pub(crate) async fn new_blocks(
grpc: &MassaPublicGrpc,
request: Request<Streaming<NewBlocksRequest>>,
) -> Result<NewBlocksStreamType, GrpcError>Expand description
Creates a new stream of new produced and received blocks
pub(crate) async fn new_blocks(
grpc: &MassaPublicGrpc,
request: Request<Streaming<NewBlocksRequest>>,
) -> Result<NewBlocksStreamType, GrpcError>Creates a new stream of new produced and received blocks